#!/bin/bash
#
# Last update: 2023.5.18

clear
echo "===================================================================================================="
echo ""
echo "此為 Ubuntu 2004 LTS 系統自動安裝 cPanel 程式"
echo ""
echo "注意事項:"
echo "01.目前不支援 Cloudlinux，相關程式安裝已註解。"
echo "02.不提供 Openresty 安裝，相關程式安裝已刪除。"
echo "03.目前不支援 lsapi，相關程式安裝已註解，改用 mod_fcgid"
echo "04.目前不支援 Kernelcare 安裝，相關程式安裝已刪除。"
echo "05.Easyapache4安裝套件因名稱不同，相關 json 已重新製作新的，目前 PHP 支援 73 74 80 81"
echo "06.目前 MySQL 僅支援 8.0"
echo ""
echo "===================================================================================================="
sleep 10


# 如果系統為 CentOS or Almalinux，會直接離開 Script
if [ -e /etc/redhat-release ]; then
   echo "此主機系統為 CentOS or Almalinux，無法使用此 Script"
   exit
fi

# 如果系統已經安裝cPanel，會直接離開 Script
if [ -e /usr/local/cpanel/cpanel ]; then
   echo "此主機已經安裝 cPanel，無法使用此 Script"
   exit
fi

# Change the operating state
#systemctl set-default TARGET.target

# Disable SELinux
sed -i 's/^SELINUX=.*/SELINUX=disabled/g' /etc/selinux/config
setenforce 0

# 設定 nameserver (只會詢問一次)
if [ ! -e /usr/local/src/set_nameserver ]; then

ans=''
while [ "$ans"=="1" -o "$ans"=="2" -o "$ans"=="3" ]; do
   clear
   echo "==================================================="
   echo "  請選擇主機存放位置，以便設定正確的 nameserver    "
   echo "                                                   "
   echo "  (1) 遠傳 (2) 宏遠 & 溪城 (3) 國外主機            "
   echo "==================================================="
   read -e -p "您的選擇是 ? ==> (1/2/3): " -i "" ans
   case $ans in
        1)
           sed -i '/nameserver/d' /etc/resolv.conf
           echo "nameserver 103.17.9.155" >> /etc/resolv.conf
           echo "nameserver 103.17.11.155" >> /etc/resolv.conf
           echo "nameserver 168.95.1.1" >> /etc/resolv.conf
           touch /usr/local/src/set_nameserver
           break;;
        2)
           sed -i '/nameserver/d' /etc/resolv.conf
           echo "nameserver 168.95.1.1" >> /etc/resolv.conf
           echo "nameserver 8.8.8.8" >> /etc/resolv.conf
           touch /usr/local/src/set_nameserver
           break;;
        3)
           sed -i '/nameserver/d' /etc/resolv.conf
           echo "nameserver 8.8.8.8" >> /etc/resolv.conf
           echo "nameserver 4.2.2.1" >> /etc/resolv.conf
           touch /usr/local/src/set_nameserver
           break;;
        *)
           echo ""
           echo "輸入選擇為不正確 : $ans，請參考以下說明，輸入正確值"
           echo ""
           echo "(1) 遠傳 (2) 宏遠 & 溪城 (3) 國外主機"
           sleep 3
           continue;;
   esac
done

fi

# 將 "[root@cpXX ~]#" 改成 "root@cpXX [~]#" (只會設定一次)
# \u 使用者名稱 \h 主機名稱 \w 目前工作目錄
# 讓 ll 指令可以顯示隱藏檔案
if [ ! -e /usr/local/src/set_ps1 ]; then
PS1="\u@\h [\w]# "
echo 'PS1="\u@\h [\w]# "' >> ~/.bashrc 
#unalias ll
alias ll='ls -l --color=tty -F -a -b -T 0'
touch /usr/local/src/set_ps1
fi

# 設定時區區域為 Taipei (只會設定一次)
if [ ! -e /usr/local/src/set_timezone ]; then
/usr/bin/timedatectl set-timezone Asia/Taipei
touch /usr/local/src/set_timezone
fi

# 紀錄開始安裝時間
echo "開始安裝 : `date`" > /root/install_date

# 更新系統套件並設定 Cron (只會設定一次)
if [ ! -e /usr/local/src/set_apt_cron ]; then
apt update ; apt -y upgrade
/usr/bin/echo "0 6 * * * root apt update ; apt -y upgrade > /dev/null 2>&1" >> /etc/crontab
touch /usr/local/src/set_apt_cron
fi

# 安裝 ntpdate、關閉 ntpd 服務、編寫 /etc/crontab，加入 ntpdate 校時 (只會詢問一次)

if [ ! -e /usr/local/src/set_ntpdate_cron ]; then

apt install ntpdate -y

clear

echo "(1) 國內 使用 103.17.9.155 外網 (DNS-01)"
/usr/sbin/ntpdate 103.17.9.155
echo "(2) 國內 使用 10.100.9.155 內網 (DNS-01)"
/usr/sbin/ntpdate 10.100.9.155
echo "(3) 國外 使用 10.168.32.155 內網 (c.g-dns.com)"
/usr/sbin/ntpdate 10.168.32.155
echo "(4) 客戶主機 使用 tock.stdtime.gov.tw"
/usr/sbin/ntpdate tock.stdtime.gov.tw

ans=''
while [ "$ans"=="1" -o "$ans"=="2" -o "$ans"=="3" -o "$ans"=="4" ]; do
   echo "============================================================"
   echo "                                                            "
   echo "  請選擇可正常同步的 ntp 位置，以便設定正確的 ntpdate Cron  "
   echo "                                                            "
   echo "  ( 台灣請選擇國內 、 台灣以外請選擇國外 )                  "
   echo "  ( 客戶主機請選擇第4項 )                                   "
   echo "                                                            "
   echo "============================================================"
   read -e -p "您的選擇是 ? ==> (1/2/3/4): " -i "" ans
   case $ans in
        1)
           echo "0 1 * * * root /usr/sbin/ntpdate 103.17.9.155 > /dev/null 2>&1" >> /etc/crontab
           touch /usr/local/src/set_ntpdate_cron
           break;;
        2)
           echo "0 1 * * * root /usr/sbin/ntpdate 10.100.9.155 > /dev/null 2>&1" >> /etc/crontab
           touch /usr/local/src/set_ntpdate_cron
           break;;
        3)
           echo "0 1 * * * root /usr/sbin/ntpdate 10.168.32.155 > /dev/null 2>&1" >> /etc/crontab
           touch /usr/local/src/set_ntpdate_cron
           break;;
        4)
           echo "0 1 * * * root /usr/sbin/ntpdate tock.stdtime.gov.tw > /dev/null 2>&1" >> /etc/crontab
           touch /usr/local/src/set_ntpdate_cron
           break;;
        *)
           echo ""
           echo "輸入選擇為不正確 : $ans，請參考以下說明，輸入正確值"
           echo ""
           echo "(1) 國內 使用 103.17.9.155 外網 (DNS-01)"
           echo ""
           echo "(2) 國內 使用 10.100.9.155 內網 (DNS-01)"
           echo ""
           echo "(3) 國外 使用 10.168.32.155 內網 (c.g-dns.com)"
           echo ""
           echo "(4) 客戶主機 使用 tock.stdtime.gov.tw"
           sleep 3
           continue;;
   esac
done

fi

# 設定 SSH Config 並重啟服務 (只會設定一次)
if [ ! -e /usr/local/src/update_sshd_conf ]; then
sed -i "s/^#UseDNS no/UseDNS no/g" /etc/ssh/sshd_config
/usr/bin/systemctl restart sshd.service
touch /usr/local/src/update_sshd_conf
fi

# 增加 sysctl.conf 設定 (只會設定一次)
if [ ! -e /usr/local/src/set_sysctl_conf ]; then
/usr/bin/cat <<EOF >> /etc/sysctl.conf
##################### Custom modify start #####################
 ## increase TCP max buffer size setable using setsockopt()
net.core.rmem_max = 16777216
net.core.wmem_max = 16777216
 ## increase Linux autotuning TCP buffer limits
 ## min, default, and max number of bytes to use
 ## set max to at least 4MB, or higher if you use very high BDP paths
net.ipv4.tcp_rmem = 4096 87380 16777216
net.ipv4.tcp_wmem = 4096 65536 16777216
 ## don't cache ssthresh from previous connection
net.ipv4.tcp_no_metrics_save = 1
net.ipv4.tcp_moderate_rcvbuf = 1
 ## recommended to increase this for 1000 BT or higher
net.core.netdev_max_backlog = 2500
 ## disable tcp selective acknowledgements.
net.ipv4.tcp_sack = 0
 ##enable window scaling
net.ipv4.tcp_window_scaling = 1
##################### Custom modify end #####################
EOF
/usr/sbin/sysctl -p
touch /usr/local/src/set_sysctl_conf
fi

# 關閉 ufw 防火牆 (只會設定一次)
if [ ! -e /usr/local/src/disable_ufw ]; then
iptables-save > ~/firewall.rules
systemctl stop ufw.service
systemctl disable ufw.service
touch /usr/local/src/disable_ufw
fi

# 安裝必要套件 (只會安裝一次)
if [ ! -e /usr/local/src/install_need_package ]; then
#apt install traceroute net-tools perl perl-base vim snmpd snmp curl mutt -y 
apt install traceroute net-tools vim curl mutt -y
#apt --fix-broken install -y
#apt autoremove -y
touch /usr/local/src/install_need_package
fi



### 顯示安裝 cPanel 選單 ###


# 選擇主機使用者類型
ans=''
host_use_user=''
while [ "$ans"=="1" -o "$ans"=="2" ]; do
   clear
   echo "==================================================="
   echo "  請選擇 主機使用者 類型                           "
   echo "                                                   "
   echo "  (1) 遠振虛擬主機專用(客戶主機請勿選取)           "
   echo "  (2) 客戶主機專用(單次部屬&管理服務)              "
   echo "==================================================="
   read -e -p "您的選擇是 ? ==> (1/2): " -i "" ans
   case $ans in
        1)
           host_use_user="1"
           break;;
        2)
           host_use_user="2"
           break;;
        *)
           echo ""
           echo "輸入選擇為不正確 : $ans，請參考以下說明，輸入正確值"
           echo ""
           echo "(1) 自用虛擬主機 (2) 客戶主機"
           sleep 3
           continue;;
   esac
done

sleep 1
clear


# 定義各項目預設參數

# 1.外網網卡名稱
CPANEL_INTERFACE=`ip -o link show | awk -F': ' '{print $2}'|grep -v lo|head -n 1`

# 2.Main IP
MAIN_IP=`ifconfig $CPANEL_INTERFACE | grep -Eo 'inet (addr:)?([0-9]*\.){3}[0-9]*' | grep -Eo '([0-9]*\.){3}[0-9]*' | grep -v '127.0.0.1'`

# 3.Main Share IP
MAIN_SHARE_IP="請手動輸入正確資訊"
if (("${host_use_user}" == "2")); then
   MAIN_SHARE_IP="$MAIN_IP"
fi

# 4.Hostname
SERVER_HOSTNAME=`hostname`

# 5.第一組 DNS 主機名稱
NS0="請手動輸入正確資訊"
if (("${host_use_user}" == "2")); then
   NS0=""
fi

# 6.第二組 DNS 主機名稱
NS1="請手動輸入正確資訊"
if (("${host_use_user}" == "2")); then
   NS1=""
fi

# 7.接收 System 通知郵件
CUSTOMER_EMAIL="cplog@ipmi.tw"
if (("${host_use_user}" == "2")); then
   CUSTOMER_EMAIL="請手動輸入正確資訊"
fi

# 8.接收 cPanel 通知郵件
WHM_EMAIL="whmlog@ipmi.tw"
if (("${host_use_user}" == "2")); then
   WHM_EMAIL="請手動輸入正確資訊"
fi

# 9.PHP版本(套用的 EA4 Json 設定檔)
eapver_version="73"

# 10.安裝 Openresty (Nginx)
#installnginx="yes"
#if (("${host_use_user}" == "2")); then
#   installnginx="no"
#fi

# 11.安裝 Default.htm 帳號預設頁面
installindex="yes"
if (("${host_use_user}" == "2")); then
   installindex="no"
fi

# 此套件因遭原廠檢舉，從2023.5.18發現無法繼續安裝，故註解取消使用
# 12.安裝 Let's Encrypt cPanel Plugin
#installletsencrypt="yes"
#if (("${host_use_user}" == "2")); then
#   installletsencrypt="no"
#fi

# 13.安裝本公司台灣或美國方案
installpackages="請手動輸入正確資訊"
if (("${host_use_user}" == "2")); then
   installpackages="no"
fi

# 14.安裝 CXS
installcxs="yes"
if (("${host_use_user}" == "2")); then
   installcxs="no"
fi

# 15.安裝 CageFS、PHP Selector、MySQL Governor (Cloudlinux)
#installcagefs="yes"
#if (("${host_use_user}" == "2")); then
#   installcagefs="no"
#fi

# 16.安裝 Installatron
installinstallatron="yes"
if (("${host_use_user}" == "2")); then
   installinstallatron="no"
fi

# 17.安裝 KernelCare
#kernelupdaten="yes"
#if (("${host_use_user}" == "2")); then
#   kernelupdaten="no"
#fi

# 18.安裝 Zabbix
zabbix="yes"
if (("${host_use_user}" == "2")); then
   zabbix="no"
fi

# 19.每小時寄信限制
mail_qty="300"

# 20.資料庫類型
mysql_version="8.0"

# 21.安裝 lsapi
#lsapi="yes"
#if (("${host_use_user}" == "2")); then
#   lsapi="no"
#fi


# 依照選擇主機使用者類型，顯示不同確定清單

ans=''
while [ "$ans"=="y" -o "$ans"=="q" ]; do
   clear
   echo "========================================================================"
   echo "  以下為預設選項設定，請務必確認無誤，再進行下一步                      "
   echo "                                                                        "
   
if (("${host_use_user}" == "1")) || (("${host_use_user}" == "2")); then
   echo "1.外網網卡名稱 : ${CPANEL_INTERFACE}"
fi
if (("${host_use_user}" == "1")); then
   echo "2.Main IP : ${MAIN_IP}"
fi
if (("${host_use_user}" == "1")) || (("${host_use_user}" == "2")); then
   echo "3.Main Share IP : ${MAIN_SHARE_IP}"
fi
if (("${host_use_user}" == "1")) || (("${host_use_user}" == "2")); then
   echo "4.Hostname : ${SERVER_HOSTNAME}"
fi
if (("${host_use_user}" == "1")); then
   echo "5.第一組 DNS 主機名稱 : ${NS0}"
fi
if (("${host_use_user}" == "1")); then
   echo "6.第二組 DNS 主機名稱 : ${NS1}"
fi
if (("${host_use_user}" == "2")); then
   echo "7.接收 System 通知郵件(管理員信箱) : ${CUSTOMER_EMAIL}"
fi
if (("${host_use_user}" == "2")); then
   echo "8.接收 cPanel 通知郵件(管理員信箱) : ${WHM_EMAIL}"
fi
if (("${host_use_user}" == "1")) || (("${host_use_user}" == "2")); then
   echo "9.PHP版本 : ${eapver_version}"
fi
#if (("${host_use_user}" == "1")); then
#   echo "10.安裝 Openresty : ${installnginx}"
#fi
if (("${host_use_user}" == "1")); then
   echo "11.安裝 Default.htm 帳號預設頁面 : ${installindex}"
fi
#if (("${host_use_user}" == "1")); then
#   echo "12.安裝 Let's Encrypt cPanel Plugin : ${installletsencrypt}"
#fi
if (("${host_use_user}" == "1")); then
   echo "13.安裝本公司台灣或美國方案 : ${installpackages}"
fi
if (("${host_use_user}" == "1")); then
   echo "14.安裝 CXS : ${installcxs}"
fi
#if (("${host_use_user}" == "1")) || (("${host_use_user}" == "2")); then
#   echo "15.安裝 CageFS、PHP Selector (Cloudlinux) : ${installcagefs}"
#fi
if [ "${host_use_user}" == "1" ]; then
   echo "16.安裝 Installatron : ${installinstallatron}"
fi
#if (("${host_use_user}" == "1")) || (("${host_use_user}" == "2")); then
#   echo "17.安裝 KernelCare : ${kernelupdaten}"
#fi
if (("${host_use_user}" == "1")); then
   echo "18.安裝 Zabbix : ${zabbix}"
fi
if (("${host_use_user}" == "2")); then
   echo "19.每小時寄信限制 : ${mail_qty}"
fi
if (("${host_use_user}" == "1")) || (("${host_use_user}" == "2")); then
   echo "20.資料庫類型 : ${mysql_version}"
fi
#if (("${host_use_user}" == "1")) || (("${host_use_user}" == "2")); then
#   echo "21.安裝 lsapi (Cloudlinux) : ${lsapi}"
#fi
   echo "                                                                        "
   echo "  輸入項目編號，即可修改選項設定                                        "
   echo "                                                                        "
   echo "  (y) 開始安裝 cPanel (n) 取消安裝 cPanel                               "
   echo "                                                                        "
   echo "========================================================================"
   read -e -p "您的選擇是 ?  " -i "" ans
   case $ans in
        1)
           clear
           echo ""
           echo "### 請改成正確的外網網卡名稱 ###"
           echo ""
           read -e -p "1.外網網卡名稱 : " -i "$CPANEL_INTERFACE" CPANEL_INTERFACE
           continue;;
        2)
           clear
           echo ""
           read -e -p "2.Main IP : " -i "$MAIN_IP" MAIN_IP
           continue;;
        3)
           clear
           echo ""
           echo "### 管理服務主機，請設定客戶指定的 Main Share IP ###"
           echo ""
           read -e -p "3.Main Share IP : " -i "" MAIN_SHARE_IP
           continue;;
        4)
           clear
           echo ""
           echo "虛擬主機 cpX.g-dns.com、經銷主機 reX.cx901.com(台灣) 或 urX.cx901.com(美國)"
           echo "半專屬主機 hdX.g-dns.com、進階資源主機 sdX.g-dns.com"
           echo "貼圖主機 phX.g-dns.com、立京主機 fhX.tw-dns.com "
           echo "新加坡主機 sgX.g-dns.com、香港主機 hkX.g-dns.com"
           echo "日本主機 jpX.g-dns.com"
           echo ""
           echo "### 管理服務主機，請依照管理服務安裝需求表設定 ###"
           echo ""
           read -e -p "4.Hostname : " -i "$SERVER_HOSTNAME" SERVER_HOSTNAME
           continue;;
        5)
           clear
           echo ""
           echo "虛擬主機 nsX.g-dns.com、經銷主機 nsX.cx901.com、立京主機 nsX.tw-dns.com"
           echo ""
           read -e -p "5.第一組 DNS 主機名稱 : " -i "" NS0
           continue;;
        6)
           clear
           echo ""
           echo "虛擬主機 nsX.g-dns.com、經銷主機 nsX.cx901.com、立京主機 nsX.tw-dns.com"
           echo ""
           read -e -p "6.第二組 DNS 主機名稱 : " -i "" NS1
           continue;;
        7)
           clear
           echo ""
           echo "### 請設定 Linux 需求表 管理員信箱 ###"
           echo ""
           read -e -p "7.接收 System 通知郵件(管理員信箱) : " -i "$CUSTOMER_EMAIL" CUSTOMER_EMAIL
           continue;;
        8)
           clear
           echo ""
           echo "### 請設定 Linux 需求表 管理員信箱 ###"
           echo ""
           read -e -p "8.接收 cPanel 通知郵件(管理員信箱) : " -i "$WHM_EMAIL" WHM_EMAIL
           continue;;
        9)
           clear
           # https://support.cpanel.net/hc/en-us/articles/4405080880023-What-versions-of-PHP-are-available-in-EasyApache-4-on-Ubuntu-
           echo ""
           echo "### 請依照管理服務安裝需求表設定 ###"
           echo ""
           echo "Apache 2.4 / PHP 7.3 / cgi = 73"
           echo "Apache 2.4 / PHP 7.4 / cgi = 74"
           echo "Apache 2.4 / PHP 8.0 / cgi = 80"
           echo "Apache 2.4 / PHP 8.1 / cgi = 81"
           echo ""
           echo "例如 : PHP 7.3，就是輸入 73"
           echo ""
           read -e -p "9.PHP版本 : " -i "$eapver_version" eapver_version
           continue;;
#        10)
#           clear
#           echo ""
#           echo "安裝 = yes、不安裝 = no"
#           echo ""
#           echo "### 管理服務主機，請依照管理服務安裝需求表設定 ###"
#           echo ""
#           read -e -p "10.安裝 Openresty : " -i "$installnginx" installnginx
#           continue;;
        11)
           clear
           echo ""
           echo "安裝 = yes、不安裝 = no"
           echo ""
           read -e -p "11.安裝 Default.htm 帳號預設頁面 : " -i "$installindex" installindex
           continue;;
#        12)
#           clear
#           echo ""
#           echo "安裝 = yes、不安裝 = no"
#           echo ""
#           read -e -p "12.安裝 Let's Encrypt cPanel Plugin : " -i "$installletsencrypt" installletsencrypt
#           continue;;
        13)
           clear
           echo ""
           echo "台灣 = tw、美國 = usa、不安裝 = no"
           echo "亞洲虛擬主機，請直接複製目前現有主機的方案設定檔"
           echo ""
           read -e -p "13.安裝本公司台灣或美國方案 : " -i "" installpackages
           continue;;
        14)
           clear
           echo ""
           echo "安裝 = yes、不安裝 = no"
           echo ""
           read -e -p "14.安裝 CXS : " -i "$installcxs" installcxs
           continue;;
#        15)
#           clear
#           echo ""
#           echo "安裝 = yes、不安裝 = no"
#           echo ""
#           read -e -p "15.安裝 CageFS、PHP Selector、MySQL Governor (Cloudlinux) : " -i "$installcagefs" installcagefs
#           continue;;
        16)
           clear
           echo ""
           echo "安裝 = yes、不安裝 = no"
           echo ""
           read -e -p "16.安裝 Installatron : " -i "$installinstallatron" installinstallatron
           continue;;
#        17)
#           clear
#           echo ""
#           echo "安裝 = yes、不安裝 = no"
#           echo ""
#           echo "### Standard 管理服務客戶才需要安裝 ###"
#           echo ""
#           read -e -p "17.安裝 KernelCare : " -i "$kernelupdaten" kernelupdaten
#           continue;;
        18)
           clear
           echo ""
           echo "安裝 = yes、不安裝 = no"
           echo ""
           echo "### 單次部屬不安裝，Standard 管理服務要安裝 ###"
           echo ""
           read -e -p "18.安裝 Zabbix : " -i "$zabbix" zabbix
           continue;;
        19)
           clear
           echo ""
           echo "### 管理服務主機，請依照管理服務安裝需求表設定 ###"
           echo ""
           read -e -p "19.每小時寄信限制 : " -i "$mail_qty" mail_qty
           continue;;
        20)
           clear
           echo ""
           echo "### 目前 Ubuntu 2004 僅支援 MySQL 8.0 ###"
           echo "### MySQL 請輸入 8.0 ###"
           echo ""
           read -e -p "20.資料庫類型 : " -i "$mysql_version" mysql_version
           continue;;
#        21)
#           clear
#           echo ""
#           echo "安裝 = yes、不安裝 = no"
#           echo ""
#           echo "自用虛擬主機 : 有安裝 Cloudlinux，都要安裝"
#           echo "客戶主機 : 客戶有安裝 Cloudlinux，再幫客戶安裝"
#           echo ""
#           read -e -p "21.安裝 lsapi (Cloudlinux) : " -i "$lsapi" lsapi
#           continue;;
        y)
           echo ""
           #echo "開始安裝 cPanel"

### 判斷輸入值是否正確，不正確不給安裝 ###

if [ "${MAIN_SHARE_IP}" = "請手動輸入正確資訊" ]; then
echo ""
echo "3.Main Share IP : 請手動輸入正確資訊"
sleep 3
continue
fi

if [ "${NS0}" = "請手動輸入正確資訊" ]; then
echo ""
echo "5.第一組 DNS 主機名稱 : 請手動輸入正確資訊"
sleep 3
continue
fi

if [ "${NS1}" = "請手動輸入正確資訊" ]; then
echo ""
echo "6.第二組 DNS 主機名稱 : 請手動輸入正確資訊"
sleep 3
continue
fi

if [ "${CUSTOMER_EMAIL}" = "請手動輸入正確資訊" ]; then
echo ""
echo "7.接收 cPanel 日誌郵件的電子郵件 : 請手動輸入正確資訊"
sleep 3
continue
fi

if [ "${WHM_EMAIL}" = "請手動輸入正確資訊" ]; then
echo ""
echo "8.提供聯絡信息的電子郵件 : 請手動輸入正確資訊"
sleep 3
continue
fi

if [ "${eapver_version}" != '73' ] && [ "${eapver_version}" != '74' ] && [ "${eapver_version}" != '80' ] && [ "${eapver_version}" != '81' ]; then
echo ""
echo "9.目前輸入 PHP 版本為 ${eapver_version} 無法使用，請重新輸入正確值"
sleep 3
continue
fi

if [ "${installpackages}" != "tw" ] && [ "${installpackages}" != "usa" ] && [ "${installpackages}" != "no" ]; then
echo ""
echo "13.安裝本公司台灣或美國方案，請手動輸入正確資訊"
sleep 3
continue
fi

if [ "${mysql_version}" != "8.0" ]; then
echo ""
echo "20.目前輸入 mysql 版本 ${mysql_version} 無法使用，請重新輸入正確值"
sleep 3
continue
fi

#if [ "${lsapi}" != "yes" ] && [ "${lsapi}" != "no" ]; then
#echo ""
#echo "21.是否安裝 lsapi 選項 ${lsapi} 無法使用，請重新輸入正確值"
#sleep 3
#continue
#fi

           break;;
        n)
           echo ""
           echo "取消安裝 cPanel !!!"
           echo ""
           exit;;
        *)
           echo ""
           echo "輸入選擇為不正確 : $ans，請參考以下說明，輸入正確值"
           echo ""
           echo "(y) 開始安裝 cPanel (n) 取消安裝 cPanel"
           echo ""
           echo "或者 輸入項目編號，即可修改選項設定"
           sleep 3
           continue;;
   esac
done

# 紀錄選項設定值
echo " " >> /root/install_date
echo "######################"
echo "0.主機使用者類型：${host_use_user}" >> /root/install_date
echo "1.外網網卡名稱 : ${CPANEL_INTERFACE}" >> /root/install_date
echo "2.Main IP : ${MAIN_IP}" >> /root/install_date
echo "3.Main Share IP : ${MAIN_SHARE_IP}" >> /root/install_date
echo "4.Hostname : ${SERVER_HOSTNAME}" >> /root/install_date
echo "5.第一組 DNS 主機名稱 : ${NS0}" >> /root/install_date
echo "6.第二組 DNS 主機名稱 : ${NS1}" >> /root/install_date
echo "7.接收 cPanel 日誌郵件的電子郵件 : ${CUSTOMER_EMAIL}" >> /root/install_date
echo "8.提供聯絡信息的電子郵件 : ${WHM_EMAIL}" >> /root/install_date
echo "9.PHP版本 : ${eapver_version}" >> /root/install_date
#echo "10.安裝 Openresty : ${installnginx}" >> /root/install_date
echo "11.安裝 Default.htm 帳號預設頁面 : ${installindex}" >> /root/install_date
#echo "12.安裝 Let's Encrypt cPanel Plugin : ${installletsencrypt}" >> /root/install_date
echo "13.安裝本公司台灣或美國方案 : ${installpackages}" >> /root/install_date
echo "14.安裝 CXS : ${installcxs}" >> /root/install_date
#echo "15.安裝 CageFS、PHP Selector、MySQL Governor (Cloudlinux) : ${installcagefs}" >> /root/install_date
echo "16.安裝 Installatron : ${installinstallatron}" >> /root/install_date
#echo "17.安裝 KernelCare : ${kernelupdaten}" >> /root/install_date
echo "18.安裝 Zabbix : ${zabbix}" >> /root/install_date
echo "19.每小時寄信限制 : ${mail_qty}" >> /root/install_date
echo "20.資料庫類型 : ${mysql_version}" >> /root/install_date
#echo "21.安裝 lsapi (Cloudlinux) : ${lsapi}" >> /root/install_date
echo "######################"
echo " " >> /root/install_date


########## 開始安裝 cPanel ##########


# 設定正確 hostname
/usr/bin/hostnamectl set-hostname $SERVER_HOSTNAME

# 設定 cPanel 使用更新為 stable
echo "CPANEL=stable" > /etc/cpupdate.conf

# 複製 cpanel.config 範例設定檔
mkdir -p /root/cpanel_profile
cp /opt/cpinst/cpinst/config/cpanel.config /root/cpanel_profile/

# 設定每小時寄信最大限制數量 (客戶主機 才會進行設定，自用主機都是使用預設值 300)
if [ "$host_use_user" == "2" ]; then
  sed -i "s/^maxemailsperhour=.*/maxemailsperhour=${mail_qty}/g" /root/cpanel_profile/cpanel.config
fi

# 設定資料庫類型
sed -i "s/^mysql-version=.*/mysql-version=${mysql_version}/g" /root/cpanel_profile/cpanel.config

# 複製 EA4 Json 範例設定檔 
eapver="cpanel_install_ea4_profile_php_${eapver_version}_ubuntu.json"
cp /opt/cpinst/cpinst/config/${eapver} /etc/cpanel_initial_install_ea4_profile.json

# 沒有安裝 Openresty，Apache port 置換 28080 to 80 和 28443 to 443
sed -i 's/apache_port=.*/apache_port=0.0.0.0:80/g' /root/cpanel_profile/cpanel.config
sed -i 's/apache_ssl_port=.*/apache_ssl_port=0.0.0.0:443/g' /root/cpanel_profile/cpanel.config

# 複製 wwwacct.conf 範例設定檔，置換正確的設定
cp /opt/cpinst/cpinst/config/wwwacct.conf /etc/wwwacct.conf 
sed -i "s/QQHSTNME/${SERVER_HOSTNAME}/g" /etc/wwwacct.conf
sed -i "s/QQINTERFACE/${CPANEL_INTERFACE}/g" /etc/wwwacct.conf
sed -i "s/QQWHMMAIL/${WHM_EMAIL}/g" /etc/wwwacct.conf
sed -i "s/QQMAINSHAREIP/${MAIN_SHARE_IP}/g" /etc/wwwacct.conf
sed -i "s/QQNAM1/${NS0}/g" /etc/wwwacct.conf
sed -i "s/QQNAM2/${NS1}/g" /etc/wwwacct.conf

# fix install csf display error message '*WARNING* The option "WHM > Tweak Settings > Restrict outgoing SMTP to root,'
sed -i 's/^smtpmailgidonly=0/smtpmailgidonly=1/g' /root/cpanel_profile/cpanel.config


# 開始安裝 cPanel，安裝紀錄存放 /var/log/cpanel-install.log
cd /root && curl -o latest -L https://securedownloads.cpanel.net/latest && sh latest

# 判斷 cPanel 安裝是否完成，如果失敗會直接離開 script，並寄信至 support@twnoc.net
send_alert()
{
    SUBJECTLINE="`hostname` 主機 cPanel 安裝失敗"
    echo "cPanel 安裝失敗，請登入 `hostname` 主機確認"  | mutt -s "$SUBJECTLINE" support@twnoc.net
    exit
}
x=$(/usr/local/cpanel/cpanel -V 2>/dev/null)
if [ "$x" ]; then
  echo "cPanel installation Complete"
  # 刪除安裝檔案
  rm -f /root/latest
else
  echo "cPanel installation Fail !"
  send_alert
  exit
fi


# 更新 cPanel license & install snmpd
/usr/local/cpanel/cpkeyclt

# 安裝 Account DNS Check cPanel/WHM Plugin
cd /usr/local/src
wget http://download.ndchost.com/accountdnscheck/latest-accountdnscheck
sh latest-accountdnscheck
rm -f /usr/local/src/latest-accountdnscheck
rm -rf /usr/local/src/installd-accountdnscheck

# 增加 cPanel theme style
GITBIN="/usr/local/cpanel/3rdparty/bin/git"
mkdir -p /var/cpanel/customizations/styled/
cd /var/cpanel/customizations/styled/
$GITBIN clone https://github.com/longster/cP-Starter-Dark.git
$GITBIN clone https://github.com/longster/cP-Starter-Light.git

# register appconfig for csf.php & restoreacct.conf
# check command : whmapi1 get_appconfig_application_list
if [ "$host_use_user" == "1" ]; then
/usr/local/cpanel/bin/register_appconfig /opt/cpinst/cpinst/config/unblockip.conf
mkdir -p /usr/local/cpanel/whostmgr/docroot/cgi/unblockip/
/bin/cp -f /opt/cpinst/moni_script/csf.php /usr/local/cpanel/whostmgr/docroot/cgi/unblockip/
#/usr/local/cpanel/bin/register_appconfig /opt/cpinst/cpinst/config/restoreacct.conf
fi

# 安裝 CSF 套件
apt remove ufw -y
apt install perl zip unzip libwww-perl sendmail-bin -y
/bin/bash /opt/cpinst/cpinst/install_script/csf.sh ${host_use_user}

# 開啟 Shell Fork Bomb Protection
#perl -I/usr/local/cpanel -MCpanel::LoginProfile -le 'print [Cpanel::LoginProfile::install_profile('limits')]->[1];'

# 安裝 Default.htm 帳號預設頁面
# 如果預設要讓網站開啟 gzip 壓縮，可建立 .htaccess 於預設帳號目錄內，加入以下網頁內說明的語法 (此設定尚未套用，往後有需要再說)
# https://gtmetrix.com/enable-gzip-compression.html
if [ "$installindex" == "yes" ]; then
  mkdir -p /root/cpanel3-skel/public_html
  cp /opt/cpinst/cpinst/config/Default.htm /root/cpanel3-skel/public_html
fi

# 安裝 Let's Encrypt cPanel Plugin (For Ubuntu 2004)
#if [ "$installletsencrypt" == "yes" ]; then
#  wget -qO - https://cpanel.fleetssl.com/downloads/packaging.key | sudo apt-key add -
#  echo 'deb https://r.cpanel.fleetssl.com/ubuntu focal main' > /etc/apt/sources.list.d/fleetssl.list
#  wget -O /etc/letsencrypt-cpanel.licence http://g-host.net/gay/scripts/letsencrypt-cpanel/letsencrypt-cpanel.licence
#  chmod 0400 /etc/letsencrypt-cpanel.licence
#  apt-get update && apt-get -y install letsencrypt-cpanel
#  mainip=`cat /var/cpanel/mainip`
#  lets=`whmapi1 api_token_list | grep 'name: letsencrypt' | awk '{print $2}'` ; whmapi1 api_token_update token_name="$lets" whitelist_ip="$mainip"
#fi

# 啟用 Two-Factor Authentication
whmapi1 twofactorauth_enable_policy

# 安裝本公司台灣或美國方案
if [ "$installpackages" == "tw" ]; then
  /bin/cp -f /opt/cpinst/cpinst/config/packages/tw/* /var/cpanel/packages/
fi
if [ "$installpackages" == "usa" ]; then
  /bin/cp -f /opt/cpinst/cpinst/config/packages/usa/* /var/cpanel/packages/
fi

# 安裝 CXS (For Ubuntu 2004 test ok Ex.2022/5/18)
if [ "$installcxs" == "yes" ]; then
  # https://configserver.com/cp/cxs.html
  # https://configserver.com/cp/cxsinstaller.html
  /bin/bash /opt/cpinst/cpinst/install_script/cxs.sh
fi

# 安裝 Installatron (For Ubuntu 2004 test ok Ex.2022/5/18)
if [ "$installinstallatron" == "yes" ]; then
  # https://installatron.com/plugin/download/cpanelwhm
  cd ~
  wget https://data.installatron.com/installatron-plugin.sh
  chmod +x installatron-plugin.sh
  ./installatron-plugin.sh -f
fi

# 安裝 CageFS、MySQL Governor
#if [ "$installcagefs" == "yes" ]; then
#  /bin/bash /opt/cpinst/cpinst/install_script/cagefs.sh
#  yum install governor-mysql -y

#if [ "$mysql_version" == "5.7" ]; then
#/usr/share/lve/dbgovernor/db-select-mysql --mysql-version=mysql57
#/usr/share/lve/dbgovernor/mysqlgovernor.py --install
#fi
#if [ "$mysql_version" == "8.0" ]; then
#/usr/share/lve/dbgovernor/db-select-mysql --mysql-version=mysql80
#/usr/share/lve/dbgovernor/mysqlgovernor.py --install-beta
#fi
#if [ "$mysql_version" == "10.3" ]; then
#/usr/share/lve/dbgovernor/db-select-mysql --mysql-version=mariadb103
#/usr/share/lve/dbgovernor/mysqlgovernor.py --install
#fi

#  /bin/bash /opt/cpinst/cpinst/install_script/mysqlgovernor.sh
#  touch /etc/container/cl-quotas.dat
#fi

# 安裝 PHP Selector or Python Selector
#if [ "$installcagefs" == "yes" ]; then 
#   /bin/bash /opt/cpinst/cpinst/install_script/phpselector.sh
#fi

# 關閉 Compiler Access
/scripts/compilers off

# 設定 Edit System Mail Preferences
echo "cpanel: ${CUSTOMER_EMAIL}" > /etc/localaliases
echo 'nobody: /dev/null' >> /etc/localaliases
echo "root: ${CUSTOMER_EMAIL}" >> /etc/localaliases

# 更新 /etc/my.cnf 設定檔
mv /etc/my.cnf /etc/my.cnf_bak
if [ "$mysql_version" == "8.0" ]; then
cp /opt/cpinst/cpinst/config/my_8.txt /etc/my.cnf
sed -i "s/^tmpdir/#tmpdir/g" /etc/my.cnf
sed -i "s/^log-error/#log-error/g" /etc/my.cnf
fi
/scripts/restartsrv_mysql
ln -s /var/log/mysql/error.log /var/lib/mysql/`hostname`.err
ln -s /var/log/mysql/error.log /var/lib/mysql/error.err

# 複製 Contact Manager 範例設定檔
mv /var/cpanel/icontact_event_importance.json /var/cpanel/icontact_event_importance.json_bak
/bin/cp -f /opt/cpinst/cpinst/config/icontact_event_importance.json /var/cpanel/icontact_event_importance.json
/bin/cp -f /opt/cpinst/cpinst/config/clevels.conf /var/cpanel/clevels.conf

# Apache Configuration > Include Editor
/usr/bin/cat <<EOF >> /usr/local/apache/conf/includes/post_virtualhost_global.conf
<IfModule mod_fcgid.c>
# scan interval for busy timeout process
FcgidBusyScanInterval 90

# a FastCGI application will be killed after handling a request for FcgidBusyTimeout
FcgidBusyTimeout 600

# scan interval for exited process
FcgidErrorScanInterval 3

# Mirror the PHP cgi.fix_pathinfo setting
FcgidFixPathinfo 1

# scan interval for idle timeout process
FcgidIdleScanInterval 70

# An idle FastCGI application will be killed after FcgidIdleTimeout
FcgidIdleTimeout 360

# Communication timeout to FastCGI server
FcgidIOTimeout 1000

# maximum number of FastCGI application processes
FcgidMaxProcesses 1000

# Max process count of one class of FastCGI application
FcgidMaxProcessesPerClass 100

# maximum size of a request which will be held in memory
FcgidMaxRequestInMem 268435456

# maximum HTTP request length (128M)
FcgidMaxRequestLen 134217728

# Max requests handled by each FastCGI application
FcgidMaxRequestsPerProcess 0

# Min process count of one class of FastCGI application
FcgidMinProcessesPerClass 3

# CGI output buffer size
FcgidOutputBufferSize 1048576

# Header name which will be passed to FastCGI as environment variable
FcgidPassHeader HTTP_AUTHORIZATION

# maximum FastCGI application process lifetime
FcgidProcessLifeTime 300

# Each spawn adds this value to the process activity score
FcgidSpawnScore 1

# Maximum value of the process activity score which allows a spawn to occur
FcgidSpawnScoreUpLimit 10

# Each terminated process adds this value to the process activity score.
FcgidTerminationScore 2

# Amount subtracted from process activity score each second
FcgidTimeScore 2

# scan interval for zombie process
FcgidZombieScanInterval 3
</IfModule>
EOF
apt install ea-apache24-mod-reqtimeout -y
/usr/bin/cat <<EOF >> /usr/local/apache/conf/includes/pre_main_global.conf
<IfModule mod_reqtimeout.c>
RequestReadTimeout header=10-20,MinRate=500 body=20-600,MinRate=500
</IfModule>
EOF
/usr/bin/cat <<EOF >> /etc/apache2/conf.d/includes/pre_virtualhost_global.conf
SSLUseStapling off
EOF
/scripts/rebuildhttpdconf
/scripts/restartsrv_httpd

# Exim Configuration Manager
# https://docs.cpanel.net/whm/scripts/the-cpconftool-script/82/
mkdir /var/cpanel/config.backups/
/bin/cp /opt/cpinst/cpinst/config/whm-config-backup-cpanel__smtp__exim-108.002000-1681175056.tar.gz /var/cpanel/config.backups/
/usr/local/cpanel/bin/cpconftool --restore=/var/cpanel/config.backups/whm-config-backup-cpanel__smtp__exim-108.002000-1681175056.tar.gz --modules=cpanel::smtp::exim
echo '*: '`cat /var/cpanel/mainip` > /etc/mailips
echo '*: '`hostname` > /etc/mailhelo

# pure-ftpd
/scripts/setupftpserver --force pure-ftpd
rm -f /var/cpanel/conf/pureftpd/main.cache
mv /var/cpanel/conf/pureftpd/main /var/cpanel/conf/pureftpd/main.backup
/bin/cp -f /opt/cpinst/cpinst/config/pureftpd_main /var/cpanel/conf/pureftpd/main
touch /var/cpanel/conf/pureftpd/local
echo 'ForcePassiveIP: ~' >> /var/cpanel/conf/pureftpd/local
echo 'PassivePortRange: 30000 50000' >> /var/cpanel/conf/pureftpd/local
/scripts/restartsrv_ftpserver

# 安裝 SNMP
apt install snmpd snmp -y
mv -f /etc/snmp/snmpd.conf /etc/snmp/snmpd.conf.bak
wget -O /etc/snmp/snmpd.conf https://cpanel.net.tw/tool/snmp/snmpd-conf.txt 
echo "syslocation "`uname -a` >>  /etc/snmp/snmpd.conf
systemctl restart snmpd
systemctl enable snmpd

# 安裝 Memcachd
apt install memcached -y
systemctl daemon-reload
systemctl enable memcached.service
systemctl start memcached.service
apt install ea-php${eapver_version}-php-memcache -y
apt install ea-php${eapver_version}-php-memcached -y

# 關閉 Core Dump
cat /etc/security/limits.conf  |grep -v  . -n -m 1 |cut -d : -f1 |xargs -i  sed -i  '{}c \\*\thard\tcore\t0' /etc/security/limits.conf
echo 'kernel.core_pattern = /dev/null/' >> /etc/sysctl.conf
echo 'fs.suid_dumpable = 0' >> /etc/sysctl.conf
sysctl -p
echo 'ulimit -S -c 0 > /dev/null 2>&1' >> /etc/profile

# 安裝 imagick
#apt install imagemagick libmagickwand-dev libmagickcore-dev -y
#autodetect | /opt/cpanel/ea-php${eapver_version}/root/usr/bin/pecl install imagick
#sed -i 's/^expose_php.*.=.*/expose_php = off/g' /opt/cpanel/ea-php${eapver_version}/root/etc/php.ini
#sed -i 's/^log_errors.*.=.*/log_errors = off/g' /opt/cpanel/ea-php${eapver_version}/root/etc/php.ini
#sed -i 's/^enable_dl.*.=.*/enable_dl = Off/g' /opt/cpanel/ea-php${eapver_version}/root/etc/php.ini
#sed -i 's/^disable_functions.*.=.*/disable_functions = symlink,show_source, system, exec, shell_exec, passthru, popen, proc_open, proc_close, proc_get_status, proc_nice, proc_terminate, escapeshellarg, escapeshellcmd, ini_alter, define_syslog_variables,posix_uname,posix_getpwuid,posix_getpwnam, apache_child_terminate,posix_kill,posix_mkfifo,posix_setpgid,posix_setsid,posix_setuid,proc_terminate, posix_uname, diskfreespace, leak,base64_encodem,eval, apache_child_terminate, apache_setenv/g' /opt/cpanel/ea-php${eapver_version}/root/etc/php.ini
#sed -i 's/date\.timezone.*.=.*/date\.timezone="Asia\/Taipei"/g' /opt/cpanel/ea-php${eapver_version}/root/etc/php.ini
#sed -i 's/memory_limit.*.=.*/memory_limit = 128M/g' /opt/cpanel/ea-php${eapver_version}/root/etc/php.ini
#/usr/local/cpanel/bin/rebuild_phpconf --default=ea-php${eapver_version}

# 關閉 PHP-FPM
whmapi1 php_set_default_accounts_to_fpm default_accounts_to_fpm=0

# 安裝 Zabbix
if [ "$zabbix" == "yes" ]; then

cd /root
git clone git@git.twnoc.net:nicole/zabbix.git
/bin/bash /root/zabbix/zabbix_install.sh

if [ "$host_use_user" == "1" ]; then

if [ ! -e /home/phpchk ]; then

# 避免建立的帳號無法正常切換php版本，因此再次執行重裝套件以及更新設定 2019-9-4 Jacky
#yum reinstall cagefs lvemanager lve-stats lve-utils -y
#/bin/mv -f /etc/cl.selector/php.conf /etc/cl.selector/php.conf.backup
#cp -f /opt/cpinst/cpinst/config/php_conf /etc/cl.selector/php.conf
#sed -i 's/^expose_php.*.=.*/expose_php = Off/g' /opt/alt/php*/etc/php.ini
#sed -i 's/^log_errors.*.=.*/log_errors = Off/g' /opt/alt/php*/etc/php.ini
#sed -i 's/^enable_dl.*.=.*/enable_dl = Off/g' /opt/alt/php*/etc/php.ini
#sed -i 's/^disable_functions.*.=.*/disable_functions = symlink,show_source, system, exec, shell_exec, passthru, popen, proc_open, proc_close, proc_get_status, proc_nice, proc_terminate, escapeshellarg, escapeshellcmd, ini_alter, define_syslog_variables,posix_uname,posix_getpwuid,posix_getpwnam, apache_child_terminate,posix_kill,posix_mkfifo,posix_setpgid,posix_setsid,posix_setuid,proc_terminate, posix_uname, diskfreespace, leak,base64_encodem,eval, apache_child_terminate, apache_setenv/g' /opt/alt/php*/etc/php.ini
#sed -i 's/date\.timezone.*.=.*/date\.timezone="Asia\/Taipei"/g' /opt/alt/php*/etc/php.ini
#sed -i 's/^;memory_limit.*.=.*/memory_limit = 128M/g' /opt/alt/php*/etc/php.ini
#sed -i 's/^upload_max_filesize.*/upload_max_filesize = 32M/g' /opt/alt/php*/etc/php.ini
#cagefsctl --remount-all
#cagefsctl --force-update

/usr/bin/hostnamectl set-hostname $SERVER_HOSTNAME
/usr/local/cpanel/bin/set_hostname $SERVER_HOSTNAME
phpchk_domain=`hostname -s`.phpchk.com

whmapi1 createacct username=phpchk domain=${phpchk_domain}

fi

#新增 php_select_test.php 程式
#touch /home/phpchk/public_html/php_select_test.php
#chown phpchk.phpchk /home/phpchk/public_html/php_select_test.php
#cat << EOF > /home/phpchk/public_html/php_select_test.php
#<?
#echo phpversion();
#?>
#EOF

#新增 ip.php 程式
#touch /home/phpchk/public_html/ip.php
#chown phpchk.phpchk /home/phpchk/public_html/ip.php
#cat << EOF > /home/phpchk/public_html/ip.php
#<?php
#echo \$_SERVER['REMOTE_ADDR'] . " " ;
#echo \$_SERVER['SERVER_ADDR'] ;
#?>
#EOF

#新增 remoteip.php 程式
#touch /home/phpchk/public_html/remoteip.php
#chown phpchk.phpchk /home/phpchk/public_html/remoteip.php
#mainip=`cat /var/cpanel/mainip`
#cat << EOF > /home/phpchk/public_html/remoteip.php
#<?php
#\$ch = curl_init();
#curl_setopt(\$ch,CURLOPT_URL,"http://${phpchk_domain}/ip.php");
#curl_setopt(\$ch, CURLOPT_INTERFACE, "$mainip"); //ip 請填入此主機 main ip
#curl_setopt(\$ch,CURLOPT_HEADER,0);//是否輸出header
#\$out = curl_exec(\$ch);
#curl_close(\$ch);
#?>
#EOF

fi

fi

# Paper_lantern > 調整顯示功能
if [ "$host_use_user" == "1" ]; then
cd /var/cpanel/features/
echo "" > default
echo "" > photo
echo "" > single
echo "" > addon
echo "" > single-hd
echo "" > disabled
cat /opt/cpinst/cpinst/config/feature/default > 'default'
cat /opt/cpinst/cpinst/config/feature/photo > 'photo'
cat /opt/cpinst/cpinst/config/feature/single > 'single'
cat /opt/cpinst/cpinst/config/feature/addon > 'addon'
cat /opt/cpinst/cpinst/config/feature/single-hd > 'single-hd'
cat /opt/cpinst/cpinst/config/feature/disabled > 'disabled'

# 關閉MySQL遠端功能選項顯示
touch /usr/local/cpanel/base/frontend/jupiter/dynamicui/dynamicui_hide_icon.conf
echo "file=>remote_mysql,skipobj=>1" > \
/usr/local/cpanel/base/frontend/jupiter/dynamicui/dynamicui_hide_icon.conf
fi

# cPanel面板更新翻譯
/opt/cpinst/cpinst/install_script/themes.sh

# 限制用戶切換面板
if [ "$host_use_user" == "1" ]; then
echo "jupiter" > /var/cpanel/themes.conf
fi

# 安裝 Safe-rm
if [ "$host_use_user" == "1" ]; then
/opt/cpinst/cpinst/install_script/safe-rm.sh
fi

# 幫 hostname 安裝 免費憑證
if [ "$host_use_user" == "1" ]; then
/usr/local/cpanel/bin/checkallsslcerts
fi

# 安裝 lsapi
#if [ "$lsapi" == "yes" ]; then
#/opt/cpinst/cpinst/install_script/lsapi.sh
#fi

# 安裝 mod_fcgid，設定主機全部 PHP 版本 Handlers 改成 fcgid (因為沒有lsapi，所以統一改用fcgi)
/opt/cpinst/cpinst/install_script/fcgi_ubuntu.sh

# 關閉 cPHulk
whmapi1 configureservice service=cphulkd enabled=0 monitored=0

# 阻擋客戶網站被存取.git目錄與.git與.env檔案
cp /opt/cpinst/cpinst/config/deny_git.conf /etc/apache2/conf.d/
cp /opt/cpinst/cpinst/config/deny_env.conf /etc/apache2/conf.d/
/scripts/restartsrv_httpd

# 監控主機 sshd Port 22 是否有被 try
if [ "$host_use_user" == "1" ]; then
echo "0 * * * * root /bin/bash /opt/cpinst/jacky_script/check_sshd_ubuntu.sh" >> /etc/crontab
fi

# 監控主機 LOAD
if [ "$host_use_user" == "1" ]; then
echo "*/5 * * * * root /bin/bash /opt/cpinst/jacky_script/check_load.sh" >> /etc/crontab
fi

# 每日16:00執行SQL自動備份
if [ "$host_use_user" == "1" ]; then
echo '0 16 * * * root script -c /opt/cpinst/jacky_script/daily_dump_all_sql.sh /backup/sqldump_error.log' >> /etc/crontab
fi

# fix not open webmail for roundcube problem
/usr/local/cpanel/bin/update-roundcube-db

# 自製 Suspend Page
if [ "$host_use_user" == "1" ]; then
mkdir -p /var/cpanel/webtemplates/root/english/
cp /opt/cpinst/cpinst/config/suspended.tmpl /var/cpanel/webtemplates/root/english/
cp /opt/cpinst/cpinst/config/moving.tmpl /var/cpanel/webtemplates/root/english/
fi

# Apache Worker偵測重啟程式 By.Webber
#yum install -y lynx
#/bin/cp /opt/cpinst/cpinst/scripts/apache_restart.sh /root/
#/bin/cp /opt/cpinst/cpinst/scripts/apache_start.sh /root/
#echo '/bin/bash /root/apache_start.sh start' >> /etc/rc.d/rc.local
#/bin/bash /root/apache_start.sh start

# 再次設定正確 hostname，避免DNS未指向，被cPanel改成xxxx.cprapid.com名稱
/usr/bin/hostnamectl set-hostname $SERVER_HOSTNAME
/usr/local/cpanel/bin/set_hostname $SERVER_HOSTNAME
echo '*: '`hostname` > /etc/mailhelo
ln -s /var/log/mysql/error.log /var/lib/mysql/`hostname`.err

# Default Style Basic
# https://support.cpanel.net/hc/en-us/articles/1500011608461-How-to-remove-the-Switch-to-Glass-banner-from-the-cPanel-interface
whmapi1 set_default type='default' name='basic'
mkdir -pv /root/cpanel3-skel/.cpanel/nvdata/
echo -n "1" > /root/cpanel3-skel/.cpanel/nvdata/xmainNewStyleBannerDismissed

# 客戶用改成另外一組 CSF GLOBAL ALLOW & DENY
if [ "$host_use_user" == "2" ]; then
sed -i 's/^GLOBAL_ALLOW.*.=.*/GLOBAL_ALLOW = "https:\/\/data.yji.tw\/csf\/glob_allow_ma.rules"/g' /etc/csf/csf.conf
csf -ra
fi

# remove WordPress-Toolkit-Plugin
# https://support.cpanel.net/hc/en-us/articles/360058369013-How-can-I-remove-the-WordPress-Toolkit-Plugin-
apt remove wp-toolkit-cpanel -y

# 修正v106語系檔案消失問題
/opt/cpinst/jacky_script/import_cplocales.sh



# 紀錄結束安裝時間
echo "結束安裝 : `date`" >> /root/install_date

# 說明已安裝完畢
echo ""
echo "ubuntu2004.sh 已執行安裝完畢，接著請依照wiki初始設定進行手動設定與確認。"
echo ""
echo "Zabbix 網頁頁面設定監控項目請參考 https://wiki.noc.tw/Zabbix_建立新主機"
echo ""

